/****************************************************************************
	Sunflower C library include file for DOS Stamp.
	Copyright 1999 Bagotronix Inc.

	This file defines constants and macros for the DOS Stamp.
****************************************************************************/

#ifndef DOSSTAMP_ALREADY_INCLUDED
#define DOSSTAMP_ALREADY_INCLUDED

#include <dos.h>

#include "stdinc.h"

#define DOSSTAMP

/*
//		Processor definition file for the AMD Am186ES microprocessor
//		Copyright (C) 1995, 1997 Paradigm Systems.  All rights reserved.
/
//		This file contains defintions for manipulating the AMD Am186ES/188ES
//		microprocessor peripheral control block.  These definitions are for
//		I/O mapped peripheral registers.
*/

#define	IOB186ES	0xFF00		// base I/O address of peripheral block

/*
//		Peripheral Control Block register offsets and definitions
*/

#define	RELREG			IOB186ES + 0xFE	/* Relocation Register */
#define	RSTCON   		IOB186ES + 0xF6	/* Reset Configuration Register */


/* System Configuration Register */
#define	AUXCON		   IOB186ES + 0xF2	/* Auxiliary Configuration Register */

#define	AUXCON_ERREN1	0x0040				/* SYSCON ERR_EN1 mask */
#define	AUXCON_RTSEN1	0x0020				/* SYSCON RTS_EN1 mask */
#define	AUXCON_ERREN0	0x0010				/* SYSCON ERR_EN0 mask */
#define	AUXCON_RTSEN0	0x0008				/* SYSCON RTS_EN0 mask */
#define	AUXCON_LSIZ		0x0004				/* SYSCON LSIZ mask */
#define	AUXCON_MSIZ		0x0002				/* SYSCON MSIZ mask */
#define	AUXCON_IOSIZ	0x0001				/* SYSCON IOSIZ mask */


/* System Configuration Register */
#define	SYSCON			IOB186ES + 0xF0	/* SYSCON Register */

#define	SYSCON_PSEN		0x8000				/* SYSCON PSEN mask */
#define	SYSCON_MCSBIT	0x4000				/* SYSCON MCSBIT mask */
#define	SYSCON_DSDEN	0x2000				/* SYSCON DSDEN mask */
#define	SYSCON_PWD		0x1000				/* SYSCON PWD mask */
#define	SYSCON_CBF		0x0800				/* SYSCON CBF mask */
#define	SYSCON_CBD		0x0400				/* SYSCON CBD mask */
#define	SYSCON_CAF		0x0200				/* SYSCON CAF mask */
#define	SYSCON_CAD		0x0100				/* SYSCON CAD mask */
#define	SYSCON_F2		0x0004				/* SYSCON F2 mask */
#define	SYSCON_F1		0x0002				/* SYSCON F1 mask */
#define	SYSCON_F0		0x0001				/* SYSCON F0 mask */


/* Enhanced Mode Control Registers */
#define	MDRAM				IOB186ES + 0xE0	/* MDRAM Register */
#define	CDRAM				IOB186ES + 0xE2	/* CDRAM Register */
#define	EDRAM				IOB186ES + 0xE4	/* EDRAM Register */


/* Watchdog Control/Status Register */
#define	WDT				IOB186ES + 0xE6	/* Watchdog Register */
#define	WDT_ENA			0x8000				/* Watchdog enable mask */
#define	WDT_INTTYPE		0x4000				/* Watchdog Int type mask */
#define	WDT_RSTFLAG		0x2000				/* Watchdog reset flag mask */
#define	WDT_NMIFLAG		0x1000				/* Watchdog NMI flag mask */
#define	WDT_TMODE		0x0800				/* Watchdog Test mode mask */
#define	WDT_COUNT		0x00ff				/* Watchdog count mask */


/* DMA Register Definitions */
#define	DMA0_CON		IOB186ES + 0xCA	/* DMA0 Control Register */
#define	DMA0_TCNT		IOB186ES + 0xC8	/* DMA0 Transfer Count Register */
#define	DMA0_DESTH		IOB186ES + 0xC6	/* DMA0 Destination High Register */
#define	DMA0_DESTL		IOB186ES + 0xC4	/* DMA0 Destination Low  Register */
#define	DMA0_SRCH		IOB186ES + 0xC2	/* DMA0 Source High Register */
#define	DMA0_SRCL		IOB186ES + 0xC0	/* DMA0 Source Low  Register */

#define	DMA1_CON		IOB186ES + 0xDA	/* DMA1 Control Register */
#define	DMA1_TCNT		IOB186ES + 0xD8	/* DMA1 Transfer Count Register */
#define	DMA1_DESTH		IOB186ES + 0xD6	/* DMA1 Destination High Register */
#define	DMA1_DESTL		IOB186ES + 0xD4	/* DMA1 Destination Low  Register */
#define	DMA1_SRCH		IOB186ES + 0xD2	/* DMA1 Source High Register */
#define	DMA1_SRCL		IOB186ES + 0xD0	/* DMA1 Source Low  Register */


/* Chip Select Register Definitions */
#define	UMCS				IOB186ES + 0xA0	/* UMCS Register */
#define	LMCS				IOB186ES + 0xA2	/* LMCS Register */
#define	MPCS				IOB186ES + 0xA8	/* MPCS Register */
#define	MMCS				IOB186ES + 0xA6	/* MMCS Register */
#define	PACS				IOB186ES + 0xA4	/* PACS Register */


/* Serial Port Control Register Definitions */
#define	SER0_CON			IOB186ES + 0x80	/* Serial Port0 Control Register */
#define	SER1_CON			IOB186ES + 0x10	/* Serial Port1 Control Register */

#define	SER_DMA2		0x8000				/* DMA2 control bit mask */
#define	SER_DMA1		0x4000				/* DMA1 control bit mask */
#define	SER_DMA0		0x2000				/* DMA0 control bit mask */
#define	SER_RSIE		0x1000				/* RSIE RX Int on error enable mask */
#define	SER_BKR			0x0800				/* Send Break */
#define	SER_TB8			0x0400				/* TB8 bit mask */
#define	SER_CEN			0x0200				/* CEN enable mask */
#define	SER_TXIE		0x0100				/* TXIE mask (generate int on TX hold empty) */
#define	SER_RXIE		0x0080				/* RXIE mask (generate int on RX) */
#define	SER_TMODE		0x0040				/* TMODE enable mask */
#define	SER_RMODE		0x0020				/* RMODE enable mask */
#define	SER_EVN			0x0010				/* Even parity mask */
#define	SER_PE			0x0008				/* Parity enable mask */
#define	SER_RMODE2		0x0004				/* MODE bit 2 mask */
#define	SER_RMODE1		0x0002				/* MODE bit 1 mask */
#define	SER_RMODE0		0x0001				/* MODE bit 0 mask */

/* Serial Port Status Register Definitions */
#define	SER0_STS			IOB186ES + 0x82	/* Serial Port0 Status Register */
#define	SER1_STS			IOB186ES + 0x12	/* Serial Port1 Status Register */

#define	SER_DBRK1		0x0400				/* Long Break Detected mask */
#define	SER_DBRK0		0x0200				/* Short Break Detected mask */
#define	SER_RB8			0x0100				/* Receive Data Bit 8 mask */
#define	SER_RDR			0x0080				/* Receive Data Ready mask */
#define	SER_THRE		0x0040				/* Transmit Hold Reg Empty mask */
#define	SER_FER			0x0020				/* Framing Error mask */
#define	SER_OER			0x0010				/* Overrun Error mask */
#define	SER_PER			0x0008				/* Parity Error mask */
#define	SER_TEMT		0x0004				/* Transmit Shift Reg Empty mask */
#define	SER_CTS			0x0002				/* CTS mask */

/* Serial Port Transmit Data */
#define	SER0_TDATA		IOB186ES + 0x84
#define	SER1_TDATA		IOB186ES + 0x14

/* Serial Port Receive Data */
#define	SER0_RDATA		IOB186ES + 0x86
#define	SER1_RDATA		IOB186ES + 0x16

/* Serial Port Baud Rate Divisor */
#define	SER0_BDIV	 	IOB186ES + 0x88	/* Xtal / BDIV / 16 = Baud */
#define	SER1_BDIV 		IOB186ES + 0x18	/* Xtal / BDIV / 16 = Baud */



/* PIO Register Definitions */
#define	PIO0_MODE		IOB186ES + 0x70	/* PIO 0 Mode Register */
#define	PIO0_DIR		IOB186ES + 0x72	/* PIO 0 Direction Register */
#define	PIO0_DATA		IOB186ES + 0x74	/* PIO 0 Data Register */
#define	PIO1_MODE		IOB186ES + 0x76	/* PIO 1 Mode Register */
#define	PIO1_DIR		IOB186ES + 0x78	/* PIO 1 Direction Register */
#define	PIO1_DATA		IOB186ES + 0x7a	/* PIO 1 Data Register */

#define	PIOCFG_NORMAL		0	// Normal pin function
#define	PIOCFG_INPUT		1	// Input with pullup/pulldown
#define	PIOCFG_OUTPUT		2	// Output
#define	PIOCFG_INPUT_NOPULL	3	// Input without pullup/pulldown

/* Timer Register Definitions */
#define	TMR0_CON		IOB186ES + 0x56	/* TMR0 Control Register */
#define	TMR0_CMPB		IOB186ES + 0x54	/* TMR0 Compare-B Register */
#define	TMR0_CMPA		IOB186ES + 0x52	/* TMR0 Compare-A Register */
#define	TMR0_COUNT		IOB186ES + 0x50	/* TMR0 Count Register */

#define	TMR1_CON		IOB186ES + 0x5E	/* TMR1 Control Register */
#define	TMR1_CMPB		IOB186ES + 0x5C	/* TMR1 Compare-B Register */
#define	TMR1_CMPA		IOB186ES + 0x5A	/* TMR1 Compare-A Register */
#define	TMR1_COUNT		IOB186ES + 0x58	/* TMR1 Count Register */

#define	TMR2_CON		IOB186ES + 0x66	/* TMR2 Control Register */
#define	TMR2_CMPA	 	IOB186ES + 0x62	/* TMR2 Compare-A Register */
#define	TMR2_COUNT  	IOB186ES + 0x60	/* TMR2 Count Register */

/* TxCON register */
#define	TCU_CONT		0x0001				/* Enable continuous mode */
#define	TCU_INT			0x2000				/* Interrupt on terminal count */
#define	TCU_INH			0x4000				/* Permit writes enable bit */
#define	TCU_EN			0x8000				/* Enable bit */


/* Interrupt Control Register Definitions */
#define	SP0_CON			IOB186ES + 0x44	/* Serial 0 Interrupt Control Register */
#define	SP1_CON			IOB186ES + 0x42	/* Serial 1 Interrupt Control Register */
#define	INT4_CON		IOB186ES + 0x40	/* Interrupt 4 Control Register */
#define	INT3_CON		IOB186ES + 0x3E	/* Interrupt 3 Control Register */
#define	INT2_CON		IOB186ES + 0x3C	/* Interrupt 2 Control Register */
#define	INT1_CON		IOB186ES + 0x3A	/* Interrupt 1 Control Register */
#define	INT0_CON		IOB186ES + 0x38	/* Interrupt 0 Control Register */
#define	DMA1INT_CON		IOB186ES + 0x36	/* DMA 1 Interrupt Control Register */
#define	DMA0INT_CON		IOB186ES + 0x34	/* DMA 0 Interrupt Control Register */
#define	TMRINT_CON		IOB186ES + 0x32	/* Timer Interrupt Control Register */

#define	INT_LTM			0x0010				/* Level Trigger Mode mask */
#define	INT_MSK			0x0008				/* Mask Bit mask */
#define	INT_PR2			0x0004				/* Priority Bit PR2 mask */
#define	INT_PR1			0x0002				/*              PR1      */
#define	INT_PR0			0x0001				/*              PR0      */

/* Interrupt Vector Definitions */
#define	SER0RX_VEC		20						/* Serial Port 0 Rx Interrupt Vector  */
#define	SER0TX_VEC		20						/* Serial Port 0 Tx Interrupt Vector  */
#define	SER1RX_VEC		17						/* Serial Port 1 Rx Interrupt Vector  */
#define	SER1TX_VEC		17						/* Serial Port 1 Tx Interrupt Vector  */
#define	TMR2_VEC		19						/* Timer 2 Interrupt Vector */
#define	TMR1_VEC		18						/* Timer 1 Interrupt Vector */
#define	INT4_VEC		16						/* Interrupt 4 Vector */
#define	INT3_VEC		15						/* Interrupt 3 Vector */
#define	INT2_VEC		14						/* Interrupt 2 Vector */
#define	INT1_VEC		13						/* Interrupt 1 Vector */
#define	INT0_VEC		12						/* Interrupt 0 Vector */
#define	DMA1_VEC		11						/* DMA 1 Interrupt Vector */
#define	DMA0_VEC		10						/* DMA 0 Interrupt Vector */
#define	TMR0_VEC		8						/* Timer 0 Interrupt Vector */

/* Interrupt Request Register Definitions */
#define	INT_REQ			IOB186ES + 0x2E	/* Interrupt Request Register */

#define	IRR_SP0			0x0400				/* Int Req Reg - SP0 Int mask */
#define	IRR_SP1			0x0200				/* Int Req Reg - SP1 Int mask */
#define	IRR_I4 			0x0100				/* Int Req Reg - I4  Int mask */
#define	IRR_I3	 		0x0080				/* Int Req Reg - I3  Int mask */
#define	IRR_I2 			0x0040				/* Int Req Reg - I2  Int mask */
#define	IRR_I1 			0x0020				/* Int Req Reg - I1  Int mask */
#define	IRR_I0	 		0x0010				/* Int Req Reg - I0  Int mask */
#define	IRR_D1 			0x0008				/* Int Req Reg - D1  Int mask */
#define	IRR_D0 			0x0004				/* Int Req Reg - D0  Int mask */
#define	IRR_TMR			0x0001				/* Int Req Reg - TMR Int mask */

/* Interrupt In Service Register Definitions */
#define	INT_INSERV		IOB186ES + 0x2C   /* Interrupt In Service Register */

#define	INSERV_SP0		0x0400				/* Int In Serv - SP0 Int mask */
#define	INSERV_SP1		0x0200				/* Int In Serv - SP1 Int mask */
#define	INSERV_I4		0x0100				/* Int In Serv - I4  Int mask */
#define	INSERV_I3		0x0080				/* Int In Serv - I3  Int mask */
#define	INSERV_I2		0x0040				/* Int In Serv - I2  Int mask */
#define	INSERV_I1		0x0020				/* Int In Serv - I1  Int mask */
#define	INSERV_I0		0x0010				/* Int In Serv - I0  Int mask */
#define	INSERV_D1		0x0008				/* Int In Serv - D1  Int mask */
#define	INSERV_D0		0x0004				/* Int In Serv - D0  Int mask */
#define	INSERV_TMR		0x0001				/* Int In Serv - TMR Int mask */

/* Interrupt Mask Register Definitions */
#define	IMASK				IOB186ES + 0x28	/* Interrupt Mask Register */

#define	IMASK_SP0		0x0400				/* Int Mask - SP0 mask */
#define	IMASK_SP1		0x0200				/* Int Mask - SP1 mask */
#define	IMASK_I4		0x0100				/* Int Mask - I4  mask */
#define	IMASK_I3		0x0080				/* Int Mask - I3  mask */
#define	IMASK_I2		0x0040				/* Int Mask - I2  mask */
#define	IMASK_I1		0x0020				/* Int Mask - I1  mask */
#define	IMASK_I0		0x0010				/* Int Mask - I0  mask */
#define	IMASK_D1		0x0008				/* Int Mask - D1  mask */
#define	IMASK_D0		0x0004				/* Int Mask - D0  mask */
#define	IMASK_TMR		0x0001				/* Int Mask - TMR mask */
#define	IMASK_ALL		0x07fd				/* Mask all interrupts */

/* Interrupt Poll Status Register Definitions */
#define	INT_PSTS			IOB186ES + 0x26	/* Interrupt Poll Status Register */

/* Interrupt Poll Register Definitions */
#define	INT_POLL			IOB186ES + 0x24	/* Interrupt Poll Register */

#define	INTREQ_MASK		0x8000				/* POLL Reg Interrupt Request mask */

/* Interrupt EOI Register Definitions */
#define	INT_EOI			IOB186ES + 0x22	/* Interrupt EOI Register */

#define	NSPEC_MASK		0x8000				/* EOI Reg Non-Specific mask */


#define SEOI(x) outport(INT_EOI,x)          /* specific EOI */
#define NEOI() outport(INT_EOI,0x8000)      /* non-specific EOI */

#define NOP() __emit__(0x90)

/* nmemonic labels for interrupt controller */
#define EDGE 0
#define LEVEL 1

#define	PCS_BASE	0x0800		// Peripheral chip selects base I/O address
#define	PCS0_BASE	PCS_BASE
#define	PCS1_BASE	(PCS_BASE + 0x0100)
#define	PCS2_BASE	(PCS_BASE + 0x0200)
#define	PCS3_BASE	(PCS_BASE + 0x0300)
#define	PCS5_BASE	(PCS_BASE + 0x0500)
#define	PCS6_BASE	(PCS_BASE + 0x0600)
#define	RTC_BASE	PCS5_BASE		// RTC base I/O address
#define	ADC_BASE	PCS6_BASE		// ADC base I/O address

#ifdef __cplusplus
	extern "C" {
#endif

void PIOconfig (UWORD, UWORD, BOOLEAN);
void IRQinit (UWORD, void interrupt (*)(), UWORD, BOOLEAN);
void mask (UWORD);
void unmask (UWORD);
UBYTE ubtobcd (UBYTE);
UBYTE bcdtoub (UBYTE);

#ifdef __cplusplus
	}
#endif



#endif
